@@ -50,19 +50,6 @@ gen_additive_mod <- function(mode = "unknown",
 
 }
 
-#' @export
-print.gen_additive_mod <- function(x, ...) {
-  cat("GAM Specification (", x$mode, ")\n\n", sep = "")
-  model_printer(x, ...)
-
-  if(!is.null(x$method$fit$args)) {
-    cat("Model fit template:\n")
-    print(show_call(x))
-  }
-
-  invisible(x)
-}
-
 #' @export
 #' @rdname parsnip_update
 #' @inheritParams gen_additive_mod
@@ -72,36 +59,18 @@ update.gen_additive_mod <- function(object,
                                     parameters = NULL,
                                     fresh = FALSE, ...) {
 
-  update_dot_check(...)
-
-  if (!is.null(parameters)) {
-    parameters <- check_final_param(parameters)
-  }
-
   args <- list(
     select_features = rlang::enquo(select_features),
     adjust_deg_free = rlang::enquo(adjust_deg_free)
   )
 
-  args <- update_main_parameters(args, parameters)
-
-  if (fresh) {
-    object$args <- args
-  } else {
-    null_args <- purrr::map_lgl(args, null_value)
-    if (any(null_args))
-      args <- args[!null_args]
-    if (length(args) > 0)
-      object$args[names(args)] <- args
-  }
-
-  new_model_spec(
-    "gen_additive_mod",
-    args     = object$args,
-    eng_args = object$eng_args,
-    mode     = object$mode,
-    method   = NULL,
-    engine   = object$engine
+  update_spec(
+    object = object,
+    parameters = parameters,
+    args_enquo_list = args,
+    fresh = fresh,
+    cls = "gen_additive_mod",
+    ...
   )
 }
 
