@@ -40,18 +40,6 @@ pls <-
     )
   }
 
-#' @export
-print.pls <- function(x, ...) {
-  cat("PLS Model Specification (", x$mode, ")\n\n", sep = "")
-  model_printer(x, ...)
-
-  if (!is.null(x$method$fit$args)) {
-    cat("Model fit template:\n")
-    print(show_call(x))
-  }
-  invisible(x)
-}
-
 # ------------------------------------------------------------------------------
 
 #' @export
@@ -77,36 +65,19 @@ update.pls <-
            parameters = NULL,
            predictor_prop = NULL, num_comp = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
-
-    if (!is.null(parameters)) {
-      parameters <- check_final_param(parameters)
-    }
 
     args <- list(
       predictor_prop    = enquo(predictor_prop),
       num_comp  = enquo(num_comp)
     )
 
-    args <- update_main_parameters(args, parameters)
-
-    if (fresh) {
-      object$args <- args
-    } else {
-      null_args <- purrr::map_lgl(args, null_value)
-      if (any(null_args))
-        args <- args[!null_args]
-      if (length(args) > 0)
-        object$args[names(args)] <- args
-    }
-
-    new_model_spec(
-      "pls",
-      args = object$args,
-      eng_args = object$eng_args,
-      mode = object$mode,
-      method = NULL,
-      engine = object$engine
+    update_spec(
+      object = object,
+      parameters = parameters,
+      args_enquo_list = args,
+      fresh = fresh,
+      cls = "pls",
+      ...
     )
   }
 
